
# This file was automatically generated by Dist::Zilla::Plugin::Alien v0.023.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use Alien::Base::ModuleBuild;

my %module_build_args = (
  "alien_build_commands" => [
    "%pconfigure --with-pic --prefix=%s"
  ],
  "alien_inline_auto_include" => [],
  "alien_install_commands" => [
    "make install"
  ],
  "alien_name" => "gpg-error",
  "alien_repository" => {
    "host" => "",
    "location" => "inc",
    "pattern" => "^libgpg-error-([\\d\\.]+)\\.tar\\.gz\$",
    "protocol" => "local"
  },
  "build_requires" => {},
  "configure_requires" => {
    "Alien::Base::ModuleBuild" => "0.002",
    "File::ShareDir" => "1.03"
  },
  "dist_abstract" => "Install and make available libgpg-error",
  "dist_author" => [
    "Alex J. G. Burzy\x{144}ski <ajgb\@cpan.org>"
  ],
  "dist_name" => "Alien-GPG-Error",
  "dist_version" => "1.21.0",
  "license" => "perl",
  "module_name" => "Alien::GPG::Error",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Alien::Base" => "0.002",
    "File::ShareDir" => "1.03",
    "parent" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => 0,
    "perl" => "5.006"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Test::More" => 0,
  "perl" => "5.006"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Alien::Base::ModuleBuild->new(%module_build_args);

$build->create_build_script;
